Target Selection
================

``target_selection`` provides the framework for defining cross-matching and target selection algorithms using the parent catalogues in :ref:`catalogdb <sdssdb:available-databases>`.

``target_selection`` can be installed with ::

  pip install -U sdss-target-selection

or directly from the `GitHub Repository <https://github.com/sdss/target_selection>`__.


Contents
--------

.. toctree::
  :maxdepth: 2
  :caption: Guides

  database
  cross-match
  target-selection
  tagging

.. toctree::
  :maxdepth: 2
  :caption: Reference

  api
  cli

.. toctree::
  :maxdepth: 1
  :caption: Guides

  Changelog <changelog>
  GitHub Repository <https://github.com/sdss/target_selection/>
  Issues <https://github.com/sdss/target_selection/issues>


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
